@@ -6,7 +6,13 @@ def play(filename):
     print(f'PLAY: {filename}')
 
 
+def test():
+    print('test')
+    pass
+
+
 ACTIONS = {
     'say': say,
     'play': play,
+    'test': test,
 }
