@@ -47,10 +47,36 @@ class EveScriptCompiler(ParseTreeVisitor):
 
     # Visit a parse tree produced by EveScriptParser#condition.
     def visitStatement(self, ctx: EveScriptParser.StatementContext):
-        return {
-            'if': self.visitExpr(ctx.expr()),
-            'then': [self.visitAction(action) for action in ctx.action()],
-        }
+        if ctx.if_statement():
+            return self.visitIf_statement(ctx.if_statement())
+        elif ctx.action():
+            return self.visitAction(ctx.action())
+
+    def visitIf_statement(self, ctx: EveScriptParser.If_statementContext):
+        if ctx.getChildCount() == 7:
+            # if..else
+            return {
+                'if': self.visitExpr(ctx.expr()),
+                'then': self.visitBlock(ctx.block()[0]),
+                'else': self.visitBlock(ctx.block()[1]),
+            }
+        else:
+            return {
+                'if': self.visitExpr(ctx.expr()),
+                'then': self.visitBlock(ctx.block()[0]),
+            }
+
+    def visitBlock(self, ctx: EveScriptParser.BlockContext):
+        statements = ctx.statement()
+        if ctx.getChild(0).getText() == '{':
+            if len(statements) > 1:
+                return [self.visitStatement(statement) for statement in statements]
+            elif len(statements) == 0:
+                return []
+            else:
+                return self.visitStatement(statements[0])
+        else:
+            return self.visitStatement(statements[0])
 
     # Visit a parse tree produced by EveScriptParser#expr.
     def visitExpr(self, ctx: EveScriptParser.ExprContext):
@@ -103,10 +129,13 @@ class EveScriptCompiler(ParseTreeVisitor):
 
     # Visit a parse tree produced by EveScriptParser#predicate.
     def visitPredicate(self, ctx: EveScriptParser.PredicateContext):
-        return {
-            'operator': self.visitOperator(ctx.operator()),
-            'operands': [self.visitOperand(operand) for operand in ctx.operand()],
-        }
+        if ctx.boolean():
+            return self.visitBoolean(ctx.boolean())
+        else:
+            return {
+                'operator': self.visitOperator(ctx.operator()),
+                'operands': [self.visitOperand(operand) for operand in ctx.operand()],
+            }
 
     # Visit a parse tree produced by EveScriptParser#operator.
     def visitOperator(self, ctx: EveScriptParser.OperatorContext):
@@ -124,14 +153,19 @@ class EveScriptCompiler(ParseTreeVisitor):
     # Visit a parse tree produced by EveScriptParser#const.
     def visitConst(self, ctx: EveScriptParser.ConstContext):
         text = ctx.getText()
-        if ctx.STRING():
+        if ctx.boolean():
+            return self.visitBoolean(ctx.boolean())
+        elif ctx.STRING():
             return text.strip('"')
         elif ctx.NUMBER():
             if '.' in text:
                 return float(text)
             else:
                 return int(text)
-        elif text == 'true':
+
+    def visitBoolean(self, ctx: EveScriptParser.BooleanContext):
+        text = ctx.getText()
+        if text == 'true':
             return True
         else:
             # text == 'false'
@@ -141,9 +175,15 @@ class EveScriptCompiler(ParseTreeVisitor):
     def visitAction(self, ctx: EveScriptParser.ActionContext):
         return {
             'func': ctx.KEYWORD().getText(),
-            'params': [self.visitParam(param) for param in ctx.param()],
+            'params': self.visitParams(ctx.params()),
         }
 
+    def visitParams(self, ctx: EveScriptParser.ParamsContext):
+        if ctx.param():
+            return [self.visitParam(param) for param in ctx.param()]
+        else:
+            return []
+
     # Visit a parse tree produced by EveScriptParser#param.
     def visitParam(self, ctx: EveScriptParser.ParamContext):
         return self.visitConst(ctx.const())
