@@ -13,7 +13,19 @@ simple_script = '''
 simple_script_ast = {
     'statements': [{
         'if': {'operator': '>', 'operands': ['$var', 0]},
-        'then': [{'func': 'action', 'params': ['$var > 0']}],
+        'then': {'func': 'action', 'params': ['$var > 0']},
+    }]
+}
+
+constant_expr = '''
+    if (true) {
+    }
+'''
+
+constant_expr_ast = {
+    'statements': [{
+        'if': True,
+        'then': [],
     }]
 }
 
@@ -72,8 +84,8 @@ multi_conditions = '''
 
 multi_conditions_ast = {
     'statements': [
-        {'if': {'operator': 'match', 'operands': ['$var1', "abc"]}, 'then': [{'func': 'action', 'params': ['success']}]},
-        {'if': {'operator': '<', 'operands': ['$var2', 0]}, 'then': [{'func': 'action', 'params': ['fail']}]},
+        {'if': {'operator': 'match', 'operands': ['$var1', "abc"]}, 'then': {'func': 'action', 'params': ['success']}},
+        {'if': {'operator': '<', 'operands': ['$var2', 0]}, 'then': {'func': 'action', 'params': ['fail']}},
     ]
 }
 
@@ -107,6 +119,77 @@ zero_actions_ast = {
     ]
 }
 
+empty_param_action = '''
+    if (true) {
+        test()
+    }
+'''
+
+empty_param_action_ast = {
+    'statements': [
+        {
+            'if': True,
+            'then': {'func': 'test', 'params': []},
+        },
+    ]
+}
+
+standalone_action = '''
+test()
+'''
+
+standalone_action_ast = {
+    'statements': [
+        {'func': 'test', 'params': []}
+    ]
+}
+
+nested_if = '''
+if (true) {
+    if (false) {
+        test()
+    }
+}
+'''
+
+nested_if_ast = {
+    'statements': [
+        {
+            'if': True,
+            'then': {
+                'if': False,
+                'then': {'func': 'test', 'params': []}
+            }
+        }
+    ]
+}
+
+if_else = '''
+if (true) {
+    action1()
+    action1()
+} else if (false) {
+    action2()
+} else
+    action3()
+'''
+
+if_else_ast = {
+    'statements': [
+        {
+            'if': True,
+            'then': [
+                {'func': 'action1', 'params': []},
+                {'func': 'action1', 'params': []},
+            ],
+            'else': {
+                'if': False,
+                'then': {'func': 'action2', 'params': []},
+                'else': {'func': 'action3', 'params': []},
+            }
+        }
+    ]
+}
 
 syntax_error = '''
 -
@@ -133,6 +216,10 @@ class CompilerTestCase(unittest.TestCase):
         ast = self.compiler.compile(simple_script)
         self.assertEqual(ast, simple_script_ast)
 
+    def test_constant_expr(self):
+        ast = self.compiler.compile(constant_expr)
+        self.assertEqual(ast, constant_expr_ast)
+
     def test_complex_expr(self):
         ast = self.compiler.compile(complex_expr)
         self.assertEqual(ast['statements'][0]['if'], complex_expr_ast)
@@ -149,6 +236,10 @@ class CompilerTestCase(unittest.TestCase):
         ast = self.compiler.compile(zero_actions)
         self.assertEqual(ast, zero_actions_ast)
 
+    def test_empty_param_action(self):
+        ast = self.compiler.compile(empty_param_action)
+        self.assertEqual(ast, empty_param_action_ast)
+
     def test_syntax_error(self):
         with self.assertRaises(antlr4.error.Errors.ParseCancellationException):
             self.compiler.compile(syntax_error, raise_exceptions=True)
@@ -156,3 +247,15 @@ class CompilerTestCase(unittest.TestCase):
     def test_comment(self):
         ast = self.compiler.compile(comment, True)
         self.assertEqual(ast, comment_ast)
+
+    def test_standalone_action(self):
+        ast = self.compiler.compile(standalone_action, True)
+        self.assertEqual(ast, standalone_action_ast)
+
+    def test_nested_if(self):
+        ast = self.compiler.compile(nested_if, True)
+        self.assertEqual(ast, nested_if_ast)
+
+    def test_if_else(self):
+        ast = self.compiler.compile(if_else, True)
+        self.assertEqual(ast, if_else_ast)
